@@ -16,7 +16,7 @@ has missing_after => 86400;
 has remove_after  => 864000;
 has tasks         => sub { {} };
 
-our $VERSION = '3.03';
+our $VERSION = '4.0';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -27,12 +27,11 @@ sub job {
 
   return undef unless my $job = $self->backend->job_info($id);
   return Minion::Job->new(
-    args     => $job->{args},
-    attempts => $job->{attempts},
-    id       => $job->{id},
-    minion   => $self,
-    retries  => $job->{retries},
-    task     => $job->{task}
+    args    => $job->{args},
+    id      => $job->{id},
+    minion  => $self,
+    retries => $job->{retries},
+    task    => $job->{task}
   );
 }
 
@@ -234,7 +233,8 @@ Backend, usually a L<Minion::Backend::Pg> object.
   $minion = $minion->backoff(sub {...});
 
 A callback used to calculate the delay for automatically retried jobs, defaults
-to C<(retries ** 4) + 15> (15, 16, 31, 96...).
+to C<(retries ** 4) + 15> (15, 16, 31, 96, 271, 640...), which means that
+roughly C<25> attempts can be made in C<21> days.
 
   $minion->backoff(sub {
     my $retries = shift;
@@ -304,7 +304,8 @@ These options are currently available:
 
   attempts => 25
 
-Number of times performing this job will be attempted, defaults to C<1>.
+Number of times performing this job will be attempted, with a delay based on
+L</"backoff"> after the first attempt, defaults to C<1>.
 
 =item delay
 
@@ -382,6 +383,51 @@ Reset job queue.
 
 Get statistics for jobs and workers.
 
+  # Check idle workers
+  my $idle = $minion->stats->{inactive_workers};
+
+These fields are currently available:
+
+=over 2
+
+=item active_jobs
+
+  active_jobs => 100
+
+Number of jobs in C<active> state.
+
+=item active_workers
+
+  active_workers => 100
+
+Number of workers that are currently processing a job.
+
+=item failed_jobs
+
+  failed_jobs => 100
+
+Number of jobs in C<failed> state.
+
+=item finished_jobs
+
+  finished_jobs => 100
+
+Number of jobs in C<finished> state.
+
+=item inactive_jobs
+
+  inactive_jobs => 100
+
+Number of jobs in C<inactive> state.
+
+=item inactive_workers
+
+  inactive_workers => 100
+
+Number of workers that are currently not processing a job.
+
+=back
+
 =head2 worker
 
   my $worker = $minion->worker;
