@@ -109,12 +109,6 @@ These fields are currently available:
 
 Job arguments.
 
-=item attempts
-
-  attempts => 25
-
-Number of times performing this job will be attempted, defaults to C<1>.
-
 =item id
 
   id => '10023'
@@ -180,8 +174,9 @@ Queue to put job in, defaults to C<default>.
   my $bool = $backend->fail_job(
     $job_id, $retries, {whatever => 'Something went wrong!'});
 
-Transition from C<active> to C<failed> state. Meant to be overloaded in a
-subclass.
+Transition from C<active> to C<failed> state, and if there are attempts
+remaining, transition back to C<inactive> with a delay based on
+L<Minion/"backoff">. Meant to be overloaded in a subclass.
 
 =head2 finish_job
 
@@ -395,6 +390,48 @@ Queue to put job in.
 
 Get statistics for jobs and workers. Meant to be overloaded in a subclass.
 
+These fields are currently available:
+
+=over 2
+
+=item active_jobs
+
+  active_jobs => 100
+
+Number of jobs in C<active> state.
+
+=item active_workers
+
+  active_workers => 100
+
+Number of workers that are currently processing a job.
+
+=item failed_jobs
+
+  failed_jobs => 100
+
+Number of jobs in C<failed> state.
+
+=item finished_jobs
+
+  finished_jobs => 100
+
+Number of jobs in C<finished> state.
+
+=item inactive_jobs
+
+  inactive_jobs => 100
+
+Number of jobs in C<inactive> state.
+
+=item inactive_workers
+
+  inactive_workers => 100
+
+Number of workers that are currently not processing a job.
+
+=back
+
 =head2 unregister_worker
 
   $backend->unregister_worker($worker_id);
