@@ -111,13 +111,12 @@ sub repair {
   );
 
   # Abandoned jobs
-  $db->query(
-    "update minion_jobs as j
-     set finished = now(), result = to_json('Worker went away'::text),
-       state = 'failed'
+  my $fail = $db->query(
+    "select id, retries from minion_jobs as j
      where state = 'active'
        and not exists(select 1 from minion_workers where id = j.worker)"
-  );
+  )->hashes;
+  $fail->each(sub { $self->fail_job(@$_{qw(id retries)}, 'Worker went away') });
 
   # Old jobs
   $db->query(
@@ -135,9 +134,8 @@ sub retry_job {
 
   return !!$self->pg->db->query(
     "update minion_jobs
-     set finished = null, priority = coalesce(?, priority),
-       queue = coalesce(?, queue), retried = now(), retries = retries + 1,
-       started = null, state = 'inactive', worker = null,
+     set priority = coalesce(?, priority), queue = coalesce(?, queue),
+       retried = now(), retries = retries + 1, state = 'inactive',
        delayed = (now() + (interval '1 second' * ?))
      where id = ? and retries = ? and state in ('failed', 'finished')
      returning 1", @$options{qw(priority queue)}, $options->{delay} // 0, $id,
@@ -159,12 +157,12 @@ sub stats {
     = $db->query($sql)->arrays->reduce(sub { $a->{$b->[0]} = $b->[1]; $a }, {});
 
   return {
+    active_jobs => $states->{active} || 0,
     active_workers   => $active,
-    inactive_workers => $all - $active,
-    active_jobs      => $states->{active} || 0,
-    inactive_jobs    => $states->{inactive} || 0,
     failed_jobs      => $states->{failed} || 0,
     finished_jobs    => $states->{finished} || 0,
+    inactive_jobs    => $states->{inactive} || 0,
+    inactive_workers => $all - $active
   };
 }
 
@@ -197,7 +195,7 @@ sub _try {
        limit 1
        for update
      )
-     returning id, args, attempts, retries, task", $id,
+     returning id, args, retries, task", $id,
     $options->{queues} || ['default'], [keys %{$self->minion->tasks}]
   )->expand->hash;
 }
@@ -205,13 +203,18 @@ sub _try {
 sub _update {
   my ($self, $fail, $id, $retries, $result) = @_;
 
-  return !!$self->pg->db->query(
+  return undef unless my $row = $self->pg->db->query(
     "update minion_jobs
      set finished = now(), result = ?, state = ?
      where id = ? and retries = ? and state = 'active'
-     returning 1", {json => $result}, $fail ? 'failed' : 'finished', $id,
-    $retries
-  )->rows;
+     returning attempts", {json => $result}, $fail ? 'failed' : 'finished',
+    $id, $retries
+  )->array;
+
+  return 1 if !$fail || (my $attempts = $row->[0]) == 1;
+  return 1 if $retries >= ($attempts - 1);
+  my $delay = $self->minion->backoff->($retries);
+  return $self->retry_job($id, $retries, {delay => $delay});
 }
 
 1;
@@ -282,12 +285,6 @@ These fields are currently available:
 
 Job arguments.
 
-=item attempts
-
-  attempts => 25
-
-Number of times performing this job will be attempted, defaults to C<1>.
-
 =item id
 
   id => '10023'
@@ -353,7 +350,9 @@ Queue to put job in, defaults to C<default>.
   my $bool = $backend->fail_job(
     $job_id, $retries, {whatever => 'Something went wrong!'});
 
-Transition from C<active> to C<failed> state.
+Transition from C<active> to C<failed> state, and if there are attempts
+remaining, transition back to C<inactive> with a delay based on
+L<Minion/"backoff">.
 
 =head2 finish_job
 
@@ -565,6 +564,48 @@ Queue to put job in.
 
 Get statistics for jobs and workers.
 
+These fields are currently available:
+
+=over 2
+
+=item active_jobs
+
+  active_jobs => 100
+
+Number of jobs in C<active> state.
+
+=item active_workers
+
+  active_workers => 100
+
+Number of workers that are currently processing a job.
+
+=item failed_jobs
+
+  failed_jobs => 100
+
+Number of jobs in C<failed> state.
+
+=item finished_jobs
+
+  finished_jobs => 100
+
+Number of jobs in C<finished> state.
+
+=item inactive_jobs
+
+  inactive_jobs => 100
+
+Number of jobs in C<inactive> state.
+
+=item inactive_workers
+
+  inactive_workers => 100
+
+Number of workers that are currently not processing a job.
+
+=back
+
 =head2 unregister_worker
 
   $backend->unregister_worker($worker_id);
